@@ -2,6 +2,7 @@ import __main__
 import fileinput
 import re
 from glob import glob
+from artify import utilities
 
 path = __main__.os.path.abspath(__main__.os.getcwd()) 
 
@@ -56,7 +57,7 @@ def get_version(filename, vtype):
                     result = 0
                     versionstr = line
                     break                
-                if __main__.arch_type == 'dotnet' and re.search(r'assembly: AssemblyVersion', line):
+                if __main__.arch_type == 'dotnet' and re.search(r'assembly: AssemblyFileVersion', line):
                     result = 0
                     versionstr = line
                     break                    
@@ -120,7 +121,7 @@ def get_version(filename, vtype):
     elif __main__.arch_type == 'dotnet' and vtype == 'standard':
         print("INFO: Architecture::: .NET/C# : MSbuild")
         strip_version = versionstr.strip()
-        clean_ver1 = re.sub('assembly: AssemblyVersion', '', strip_version)
+        clean_ver1 = re.sub('assembly: AssemblyFileVersion', '', strip_version)
         clean_ver2 = re.sub('[\[(")\]]*', '', clean_ver1)
         version_string = re.sub("[']", '', clean_ver2.strip())
         
@@ -216,6 +217,12 @@ def process_version(versionstr):
         print('ERROR: Invalid version number found')
         return __main__.sys.exit(2)
     
+    if not hasattr(__main__, 'change_type'):
+    #if not hasattr(__main__, 'change_type') and not hasattr(__main__, 'fetch_version'):
+        print("ERROR: No change type specified e.g patch, minor, major")
+        return __main__.sys.exit(2)
+
+    
     if __main__.change_type == "major":
         major = int(major) + 1
         if version_format == "standard":
@@ -287,8 +294,7 @@ def process_version(versionstr):
         if __main__.os.path.exists(java_android_build_file):
             new_version = new_version + "+" + str(versionCode)
              
-        
-             
+               
     return new_version      
         
          
@@ -354,8 +360,8 @@ def change_version_file(filepath, version, newversion):
             replace_version(filepath, old_version, new_version)        
             
     if __main__.arch_type == 'dotnet':
-        old_version = "AssemblyVersion(\"{}\")".format(version)
-        new_version = "AssemblyVersion(\"{}\")".format(newversion)
+        old_version = "AssemblyFileVersion(\"{}\")".format(version)
+        new_version = "AssemblyFileVersion(\"{}\")".format(newversion)
         replace_version(filepath, old_version, new_version)        
     
     if __main__.arch_type == 'netcore':
@@ -395,10 +401,18 @@ def modify_version():
 
     global path   
     if __main__.debug == 1:
-        print("Working directory: ",path)
+        print("DEBUG: Working directory: ",path)
     
     search_ver_text = ''
     
+    if __main__.fetch_version == 1:
+        fetched_version = utilities.get_current_application_version(path)
+        if fetched_version:
+            print("RESULT: Current App version: ", fetched_version)
+        else:
+            print("INFO: Could not find current application version")
+        return __main__.sys.exit(0)
+    
     git_checkout_command = "git checkout -b feature/modify-version"
     if not (__main__.nocommit):
         process_checkout_command = __main__.Popen(git_checkout_command, shell=True, stdout=__main__.PIPE, cwd=path)
@@ -425,7 +439,7 @@ def modify_version():
         file_list = glob('*.sln') 
         if len(file_list) >= 1:
             filename, filextension = __main__.os.path.splitext(file_list[0])
-            version_file = __main__.os.path.join(filename, filename, 'Properties', 'AssemblyInfo.cs') 
+            version_file = __main__.os.path.join(filename, 'Properties', 'AssemblyInfo.cs') 
         else:
             print("ERROR: Could not file solution file (*.sln)")
             return __main__.sys.exit(2)
@@ -433,10 +447,12 @@ def modify_version():
         version_file = __main__.version_file1
     
     if __main__.arch_type == 'netcore':
-        version_file = ''
+        version_file = __main__.version_file1
    
     
     filepath = __main__.os.path.join(path, version_file)
+
+    
     filepath_1 = __main__.os.path.join(path, __main__.version_file1)
     filepath_2 = __main__.os.path.join(path, __main__.version_file2)
     curr_version = get_version(filepath, 'standard')
