@@ -36,4 +36,10 @@ def deploy_app_awx():
 
     print("HTTP Response code: ",response.status_code)
     print("HTTP Response body: ",response.content.strip())
-    return __main__.sys.exit(0)    
+    
+    if response.status_code == 200:
+        print("INFO: Completed successfully.")
+        return __main__.sys.exit(0)    
+    else:
+        print("ERROR: Deployment failed.")
+        return __main__.sys.exit(1)
