@@ -74,6 +74,7 @@ def commit_push_changes(message):
         __main__.os.sys.exit(1)
     
     ci_user = ''
+    ci_user_email = ''
     
     if __main__.os.environ.get('GITLAB_USER_LOGIN'):
         ci_user = __main__.os.environ.get('GITLAB_USER_LOGIN')
@@ -89,6 +90,12 @@ def commit_push_changes(message):
     repository_url = __main__.os.environ.get("CI_REPOSITORY_URL")
     #git config --get remote.origin.url
     ## CI_PROJECT_URL
+    
+    if __main__.os.environ.get('GITLAB_USER_EMAIL'):
+        ci_user_email = __main__.os.environ.get('GITLAB_USER_EMAIL')
+    
+    if __main__.os.environ.get('GITHUB_USER_EMAIL'):
+        ci_user_email = __main__.os.environ.get('GITHUB_USER_EMAIL')
         
     ## Repository url with token
     ci_repo_url  = re.sub("//.*?@", auth, repository_url)
@@ -111,10 +118,10 @@ def commit_push_changes(message):
     
     if message == 'tag':
         print("INFO: Pushing tags to repository:::")
-        git_push_command = "git config user.name {}; git config user.email {}; git push --tags {} HEAD:{}".format(__main__.os.environ.get('GITLAB_USER_LOGIN'), __main__.os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, __main__.branch)
+        git_push_command = "git config user.name {}; git config user.email {}; git push --tags {} HEAD:{}".format(ci_user, ci_user_email, ci_repo_url, __main__.branch)
     else: 
         print("INFO: Pushing version changes:::")
-        git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(__main__.os.environ.get('GITLAB_USER_LOGIN'), __main__.os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, __main__.branch)
+        git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(ci_user, ci_user_email, ci_repo_url, __main__.branch)
  
     ##git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(os.environ.get('GITLAB_USER_LOGIN'), os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, os.environ.get('CI_COMMIT_BRANCH'))
     process_git_push = __main__.Popen(git_push_command, shell=True, stdout=__main__.PIPE, cwd=path)
